About
Description: About this app

# A.D.E.S.O.

## Application for Decryption, Encryption and Steganographic Operations

Steganography is the practice of concealing information within another message to avoid detection.
Encryption is the process of converting plaintext into ciphertext, which is unreadable.
This application provides both of these functionalities. Users can first encrypt their data, via a password using an AES-128 algorithm in CBC mode. Then, they can hide the encrypted data (ciphertext) within an image of their choice via steganography.

## Key Features:

- A web interface is provided to paste large plaintext objects without a terminal buffer limit.
- All encryption, decryption, encoding and decoding is done in memory.

## Tools Used:

- Front end: Svelte using SvelteKit
- API: Python 3.11.1 using Flask 2.3.2
- Cryptography: cryptography 41.0.1
- Steganography using LSB

## Gotchas:

- Large ciphertext and images can result in API lag or lockups for steganography.
- The decode operation is done on the file selected, not the image displayed on the UI.